@@ -55,7 +55,7 @@ typedef struct {
     gchar *label_text;
     gchar *url;
     gint size;
-    
+
     gboolean hide_label;
 
     /* options dialog */
@@ -103,7 +103,7 @@ static void update_search(t_search *search) {
     gtk_widget_hide(search->label);
     gtk_label_set_text(GTK_LABEL(search->label), search->label_text);
     gtk_widget_show(GTK_WIDGET(search->box));
-    if (!search->hide_label) {
+    if (search->hide_label) {
         gtk_widget_show(search->label);
     }
 }
@@ -115,7 +115,7 @@ static void search_apply_options_cb(t_search *search)
     search->url = g_strdup(gtk_entry_get_text(GTK_ENTRY(search->url_entry)));
     search->label_text = g_strdup(gtk_entry_get_text(GTK_ENTRY(search->label_entry)));
     search->size = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(search->size_spinner)));
-    search->hide_label = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search->hide_check));
+    search->hide_label = gtk_switch_get_active(GTK_SWITCH(search->hide_check));
     gtk_entry_set_width_chars(GTK_ENTRY(search->entry), search->size);
     update_search(search);
 }
@@ -136,11 +136,16 @@ static void text_entry_activate_cb(GtkWidget *widget, t_search *search)
     update_search(search);
 }
 
+void hide_check_toggled_cb(GtkWidget *widget, gboolean is_active, t_search *search)
+{
+    gtk_widget_set_sensitive (GTK_WIDGET(search->label_entry), is_active);
+}
+
 static gboolean entry_buttonpress_cb(GtkWidget *entry, GdkEventButton *event, XfcePanelPlugin *plugin)
 {
     GtkWidget *toplevel = gtk_widget_get_toplevel (entry);
 
-    if (event->button != 3 && toplevel && toplevel->window) {
+    if (event->button != 3 && toplevel && gtk_widget_get_window(toplevel)) {
         xfce_panel_plugin_focus_widget (plugin, entry);
     }
 
@@ -153,9 +158,8 @@ static gboolean entry_keypress_cb(GtkWidget *entry, GdkEventKey *event, t_search
     const gchar *key = NULL;   /* keyword */
 
     switch (event->keyval) {
-/* XXX use GDK_KEY_xx from gdkkeyssyms.h when we depend on gtk+ > 2.22 */
-        case GDK_Return:
-        case GDK_KP_Enter:
+        case GDK_KEY_Return:
+        case GDK_KEY_KP_Enter:
             key = gtk_entry_get_text(GTK_ENTRY(entry));
 
             if (do_search(search->url, key)) {
@@ -173,13 +177,12 @@ static void search_read_config(t_search *search, const gchar* filename);
 static t_search *search_new(XfcePanelPlugin *plugin)
 {
     t_search *search;
-    GtkWidget *align;
     gchar* filename;
-    
+
     search = g_new0(t_search, 1);
-    search->box = xfce_hvbox_new(!xfce_panel_plugin_get_orientation(plugin), FALSE, 0);
-    align = gtk_alignment_new(0.5, 0.5, 0, 0);
-    gtk_container_add(GTK_CONTAINER(align), search->box);
+    search->box = gtk_box_new(!xfce_panel_plugin_get_orientation(plugin), 0);
+    gtk_widget_set_halign(GTK_WIDGET(search->box), GTK_ALIGN_CENTER);
+    gtk_widget_set_valign(GTK_WIDGET(search->box), GTK_ALIGN_CENTER);
 
     /* default options */
     search->url = "http://bugs.debian.org/";
@@ -200,8 +203,8 @@ static t_search *search_new(XfcePanelPlugin *plugin)
     g_signal_connect(search->entry, "key-press-event", G_CALLBACK(entry_keypress_cb), search);
     g_signal_connect (search->entry, "button-press-event", G_CALLBACK(entry_buttonpress_cb), plugin);
 
-    gtk_container_add( GTK_CONTAINER(plugin), align);
-    gtk_widget_show_all(align);
+    gtk_container_add( GTK_CONTAINER(plugin), search->box);
+    gtk_widget_show_all(search->box);
 
     if (search->hide_label) {
         gtk_widget_hide(search->label);
@@ -229,7 +232,7 @@ static void search_write_config(XfcePanelPlugin *plugin, t_search *search)
 {
     XfceRc* rcfile;
     gchar *filename = xfce_panel_plugin_save_location(plugin, TRUE);
-    
+
     if( (filename!=NULL) && (rcfile = xfce_rc_simple_open(filename, FALSE)) )
     {
         xfce_rc_set_group(rcfile, NULL);
@@ -239,12 +242,12 @@ static void search_write_config(XfcePanelPlugin *plugin, t_search *search)
         xfce_rc_write_bool_entry(rcfile, "hidelabel", search->hide_label);
         xfce_rc_flush(rcfile);
         xfce_rc_close(rcfile);
-    }   
+    }
 }
 
 static void search_set_size(XfcePanelPlugin *plugin,gint size, t_search *search)
 {
-    /* 
+    /*
     g_print("Not Unimplemented yet : search_set_size");
     do the resize of entry :) */
 };
@@ -252,71 +255,63 @@ static void search_set_size(XfcePanelPlugin *plugin,gint size, t_search *search)
 /* options dialog */
 static void search_create_options(XfcePanelPlugin *plugin, t_search *search)
 {
-    GtkWidget *hbox, *vbox, *header;
+    GtkWidget *grid, *vbox;
     xfce_panel_plugin_block_menu(plugin);
     GtkWidget *urllabel, *textlabel, *sizelabel;
     DBG ("search_create_options");
     search->opt_dialog  = xfce_titled_dialog_new_with_buttons(_("Smartbookmark"),
-                                             NULL, GTK_DIALOG_NO_SEPARATOR,
-                                             GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+                                             GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
+                                             GTK_DIALOG_DESTROY_WITH_PARENT,
+                                             "gtk-close", GTK_RESPONSE_OK,
                                              NULL);
-    
+
     xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (search->opt_dialog), _("Preferences"));
     gtk_window_set_icon_name  (GTK_WINDOW (search->opt_dialog), "system-search");
 
-    gtk_container_set_border_width(GTK_CONTAINER (search->opt_dialog), 2);
-    
-    vbox = gtk_vbox_new(FALSE, 0);
-    gtk_widget_show(vbox);
-    gtk_container_add(GTK_CONTAINER(GTK_DIALOG(search->opt_dialog)->vbox), vbox);
+    vbox = gtk_dialog_get_content_area (GTK_DIALOG(search->opt_dialog));
 
-    DBG ("Creating hbox");
-    hbox = gtk_hbox_new(FALSE, 0);
-    gtk_widget_show(hbox);
-    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
+    grid = gtk_grid_new();
+    gtk_grid_set_column_spacing (GTK_GRID(grid), 5);
+    gtk_grid_set_row_spacing (GTK_GRID(grid), 5);
+    gtk_container_set_border_width(GTK_CONTAINER(grid), 6);
+    gtk_box_pack_start(GTK_BOX(vbox), grid, FALSE, FALSE, 0);
 
     /* text label */
     textlabel = gtk_label_new(_("Label:"));
     gtk_widget_show(textlabel);
-    gtk_box_pack_start(GTK_BOX(hbox), textlabel, FALSE, FALSE, 5);
+    gtk_grid_attach(GTK_GRID(grid), textlabel, 0, 0, 1, 1);
 
     /* text entry */
     search->label_entry = gtk_entry_new();
     gtk_widget_show(search->label_entry);
-    gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(search->label_entry), FALSE, FALSE, 0);
+    gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->label_entry), 1, 0, 1, 1);
+    gtk_widget_set_sensitive (GTK_WIDGET(search->label_entry), search->hide_label);
     /* text field */
     if(search->label_text)
         gtk_entry_set_text(GTK_ENTRY(search->label_entry), search->label_text);
     //DBG("connect signal");
     g_signal_connect (GTK_WIDGET(search->label_entry), "activate", G_CALLBACK (text_entry_activate_cb), search);
 
+    /* Hide label option */
+    search->hide_check = gtk_switch_new();
+    gtk_widget_set_tooltip_text(GTK_WIDGET(search->hide_check),_("Hide label"));
+    gtk_switch_set_active(GTK_SWITCH(search->hide_check),
+                                 search->hide_label);
+    gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->hide_check), 2, 0, 1, 1);
+    g_signal_connect (GTK_WIDGET(search->hide_check), "state-set", G_CALLBACK (hide_check_toggled_cb), search);
+
     /* size label */
     sizelabel = gtk_label_new(_("Size:"));
-    gtk_widget_show(sizelabel);
-    gtk_box_pack_start(GTK_BOX(hbox), sizelabel, FALSE, FALSE, 5);
-
+    gtk_grid_attach(GTK_GRID(grid), sizelabel, 0, 1, 1, 1);
     /* size spinner */
-    GtkObject* spinner_adj = gtk_adjustment_new (search->size, 2.0, 10.0, 1.0, 5.0, 0);
+    GtkAdjustment* spinner_adj = gtk_adjustment_new (search->size, 2.0, 10.0, 1.0, 5.0, 0);
     search->size_spinner = gtk_spin_button_new(GTK_ADJUSTMENT(spinner_adj), 1.0, 0);
-    gtk_box_pack_start(GTK_BOX(hbox), search->size_spinner, FALSE, FALSE, 0);
-    gtk_widget_show(search->size_spinner);
+    gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->size_spinner), 1, 1, 1, 1);
 
-    /* Hide label option */
-    search->hide_check = gtk_check_button_new_with_label(_("Hide label"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(search->hide_check), 
-                                 search->hide_label);
-    gtk_box_pack_start(GTK_BOX(hbox), search->hide_check, FALSE, FALSE, 5);
-    gtk_widget_show(search->hide_check);
-
-    DBG ("Creating second hbox");
-    hbox = gtk_hbox_new(FALSE, 0);
-    gtk_widget_show(hbox);
-    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
     /* url label */
     urllabel = gtk_label_new(_("URL:  "));
     gtk_label_set_use_markup(GTK_LABEL(urllabel), TRUE);
-    gtk_widget_show(urllabel);
-    gtk_box_pack_start(GTK_BOX(hbox), urllabel, FALSE, FALSE, 5);
+    gtk_grid_attach(GTK_GRID(grid), urllabel, 0, 2, 1, 1);
     /* url entry */
     search->url_entry = gtk_entry_new();
     gtk_entry_set_width_chars(GTK_ENTRY(search->url_entry), 42);
@@ -325,8 +320,9 @@ static void search_create_options(XfcePanelPlugin *plugin, t_search *search)
     if(search->url!=NULL)
         gtk_entry_set_text(GTK_ENTRY(search->url_entry), search->url);
     g_signal_connect (GTK_WIDGET(search->url_entry), "activate", G_CALLBACK (url_entry_activate_cb), search);
-    gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(search->url_entry), FALSE, FALSE, 0);
-    
+    gtk_grid_attach(GTK_GRID(grid), GTK_WIDGET(search->url_entry), 1, 2, 2, 1);
+
+    gtk_widget_show_all(search->opt_dialog);
     gtk_dialog_run (GTK_DIALOG(search->opt_dialog));
     search_apply_options_cb(search);
     gtk_widget_destroy(search->opt_dialog);
@@ -354,4 +350,3 @@ smartbookmark_construct(XfcePanelPlugin *plugin)
     g_signal_connect (plugin, "configure-plugin",
                       G_CALLBACK (search_create_options), search);
 }
-
